==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Markering",
    "Update" : "Update",
    "Create" : "Creeër",
    "Select tag…" : "Selecteren markering…",
    "Tagged files" : "Gemarkeerde bestanden",
    "Select tags to filter by" : "Selecteer markering om op te filteren",
    "No tags found" : "Geen tags gevonden",
    "Please select tags to filter by" : "Selecteer markeringen om op te filteren",
    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde markeringen",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Collaborative tags" : "Samenwerk markeringen",
    "Create and edit collaborative tags. These tags affect all users." : "Maak en bewerk samenwerkingstags. Deze tags gelden voor alle gebruikers.",
    "Select tag …" : "Selecteer tag …",
    "Name" : "Naam",
    "Delete" : "Verwijder",
    "Public" : "Openbaar",
    "Restricted" : "Beperkt",
    "Invisible" : "Verborgen",
    "Reset" : "Reset",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Size" : "Grootte",
    "Modified" : "Aangepast"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Markering",
    "Update" : "Update",
    "Create" : "Opslaan",
    "Select tag…" : "Selecteren markering…",
    "Tagged files" : "Gemarkeerde bestanden",
    "Select tags to filter by" : "Selecteer markering om op te filteren",
    "No tags found" : "Geen tags gevonden",
    "Please select tags to filter by" : "Selecteer markeringen om op te filteren",
    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde markeringen",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Collaborative tags" : "Systeemtags",
    "Create and edit collaborative tags. These tags affect all users." : "Maak en bewerk systeemtags. Deze tags raken alle gebruikers.",
    "Select tag …" : "Selecteer tag …",
    "Name" : "Tag",
    "Delete" : "Verwijder",
    "Public" : "Standaard",
    "Restricted" : "Beschermd",
    "Invisible" : "Verborgen",
    "Reset" : "Herstellen",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Size" : "Grootte",
    "Modified" : "Aangepast"
},
"nplurals=2; plural=(n != 1);");
